@@ -1,5 +1,5 @@
 package Test::Count::Base;
-$Test::Count::Base::VERSION = '0.1102';
+$Test::Count::Base::VERSION = '0.1103';
 
 use strict;
 use warnings;
@@ -30,7 +30,7 @@ Test::Count::Base - Base Class for Test::Count.
 
 =head1 VERSION
 
-version 0.1102
+version 0.1103
 
 =head1 FUNCTIONS
 
@@ -113,14 +113,6 @@ L<https://metacpan.org/release/Test-Count>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Test-Count>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -129,14 +121,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Count>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Test-Count>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
