@@ -1,5 +1,5 @@
 package Test::Count::FileMutator;
-$Test::Count::FileMutator::VERSION = '0.1102';
+$Test::Count::FileMutator::VERSION = '0.1103';
 use warnings;
 use strict;
 
@@ -83,7 +83,7 @@ sub modify
 
     my @lines = @{ $ret->{lines} };
 
-    open my $out_fh, ">", $self->_filename()
+    open my $out_fh, ">:raw", $self->_filename()
         or die "Could not open file '"
         . $self->_filename()
         . "' for writing - $!.";
@@ -173,7 +173,7 @@ Modify the file in-place.
 
 =head1 VERSION
 
-version 0.1102
+version 0.1103
 
 =head1 SYNOPSIS
 
@@ -281,14 +281,6 @@ L<https://metacpan.org/release/Test-Count>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Test-Count>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -297,14 +289,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Count>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Test-Count>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
