@@ -1,5 +1,5 @@
 package Test::Count::Filter::ByFileType::App;
-$Test::Count::Filter::ByFileType::App::VERSION = '0.1102';
+$Test::Count::Filter::ByFileType::App::VERSION = '0.1103';
 use strict;
 use warnings;
 
@@ -61,7 +61,7 @@ that filters according to the filetype.
 
 =head1 VERSION
 
-version 0.1102
+version 0.1103
 
 =head1 SYNOPSIS
 
@@ -150,14 +150,6 @@ L<https://metacpan.org/release/Test-Count>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Test-Count>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -166,14 +158,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Count>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Test-Count>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
